![PyPI - License](https://img.shields.io/badge/downloads-32k%2Fmonth-brightgreen?style=plastic) ![PyPI - License](https://img.shields.io/pypi/l/rx7?color=orange&style=plastic) ![PyPI - License](https://img.shields.io/badge/status-stable-success?style=plastic)

rx7 Library  is here to help you make your code shorter!
--------------------------------------------------------

### \- High API

### \- Special Features

### \- Most Usefull function and methods are collected.

###  **_Are you tired of importing lots of module in one script? rx7 can help you a lot_**

List of Functions:
------------------
<table style="height: 471px; width: 567px;">
  <tbody>
    <tr>
    <td style="width: 155px;">argv</td>
    <td style="width: 396px;">sys.argv (return list of given arguments from terminal)</td>
    </tr>
    <tr>
    <td style="width: 155px;">ABC</td>
    <td style="width: 396px;">Parent for classes which have abstractmethods</td>
    </tr>
    <tr>
    <td style="width: 155px;">ABCMeta</td>
    <td style="width: 396px;">Metaclass for classes which have abstractmethods</td>
    </tr>
  </tbody>
</table>

List of Functions:
------------------
<table style="height: 471px; width: 567px;">
  <tbody>
    <tr>
    <td style="width: 155px;">p()</td>
    <td style="width: 396px;">print() function. (Read Doc String)</td>
    </tr>
    <tr>
    <td style="width: 155px;">repeat(function,n)</td>
    <td style="width: 396px;">Repeat F_Name function for n times.</td>
    </tr>
    <tr>
    <td style="width: 155px;">rev(v)&nbsp; <em>(REMOVED 2.4.0)</em></td>
    <td style="width: 396px;">Reverse v and returns it. (Everything like str,list,int)&nbsp; &nbsp;</td>
    </tr>
    <tr>
    <td style="width: 155px;">read(file)</td>
    <td style="width: 396px;">Return content of the file.</td>
    </tr>
    <tr>
    <td style="width: 155px;">write(file,mode,text)</td>
    <td style="width: 396px;">Write things you want in file content.&nbsp;(Read Doc String)</td>
    </tr>
    <tr>
    <td style="width: 155px;">wait(n)<br />sleep(n)</td>
    <td style="width: 396px;">Stop code executing for n seconds</td>
    </tr>
    <tr>
    <td style="width: 155px;">cls()<br />clear()</td>
    <td style="width: 396px;">It Clears the Terminal</td>
    </tr>
    <tr>
    <td style="width: 155px;">progressbar()</td>
    <td style="width: 396px;">In-App Progressbar. (Read Doc String)</td>
    </tr>
    <tr>
    <td style="width: 155px;">cons_integer(Frst,Lst)</td>
    <td style="width: 396px;">Return string from Frst to Lst (Read Doc String) (v1.7)</td>
    </tr>
    <tr>
    <td style="width: 155px;">force(tpl,*var)</td>
    <td style="width: 396px;">Return tpl with adding var(s) to it.</td>
    </tr>
    <tr>
    <td style="width: 155px;">erase(tpl,*var)</td>
    <td style="width: 396px;">Return tpl with removing var(s) from it.</td>
    </tr>
    <tr>
    <td style="width: 155px;">replace(tpl,ind,var)</td>
    <td style="width: 396px;">Replace tpl[ind] with var</td>
    </tr>
    <tr>
    <td style="width: 155px;">insert(tpl,ind,var)</td>
    <td style="width: 396px;">Set tpl[ind] to var. (Note that tpl[ind] will be tpl[ind+1])</td>
    </tr>
    <tr>
    <td style="width: 155px;">pop(tpl,index)</td>
    <td style="width: 396px;">Remove member with index of 'index' from a tuple</td>
    </tr>
    <tr>
    <td style="width: 155px;">wait_for(button)</td>
    <td style="width: 396px;">Waits for user to press specific button.&nbsp;</td>
    </tr>
    <tr>
    <td style="width: 155px;">call_later(func,args,delay)</td>
    <td style="width: 396px;">Call func(args) after delay time.&nbsp;</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>convert_bytes(num)</div>
    </div>
    </td>
    <td style="width: 396px;">convert bytes to (KB,MB,GB,TB)</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>Input(prompt,default)</div>
    <div>default_input()</div>
    </div>
    </td>
    <td style="width: 396px;">Prompt an input message with default answer (value) <em>(ONLY ON WINDOWS)&nbsp;</em></td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>restart_app()</div>
    </div>
    </td>
    <td style="width: 396px;">Restart running python program</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>active_window_title()</div>
    </div>
    </td>
    <td style="width: 396px;">Return Active Window Title</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>open_image(path)</div>
    </div>
    </td>
    <td style="width: 396px;">Open image with default image viewer (Mac OS is not supported)</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>download(url)</div>
    </div>
    </td>
    <td style="width: 396px;">To download files with memory saver and progressbar</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>extract(file,path,pwd)</div>
    </div>
    </td>
    <td style="width: 396px;">Extract Zip file with password to path</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>screenshot(name)</div>
    </div>
    </td>
    <td style="width: 396px;">Take a screenshot and save it.</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>func_info(function)</div>
    </div>
    </td>
    <td style="width: 396px;">Print information of function</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>Check_Type</div>
    </div>
    </td>
    <td style="width: 396px;">Decorator that raise TypeError if function argument type is wrong (Read Help)</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>Progressbar()</div>
    </div>
    </td>
    <td style="width: 396px;">Generator of progressbar() which you can use it to do some stuff between your delays (Read Help)</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>pixel_color(X,Y)</div>
    </div>
    </td>
    <td style="width: 396px;">Return RGB color of pixel[X,Y]</td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>getpass(prompt)</div>
    </div>
    </td>
    <td style="width: 396px;">
    <div>
    <div>Prompt&nbsp;for&nbsp;a&nbsp;password,&nbsp;with&nbsp;echo&nbsp;turned&nbsp;off.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 155px;">
    <div>
    <div>import_module(path)</div>
    </div>
    </td>
    <td style="width: 396px;">
    <div>
    <div>Return given path (file with any extension) as a Module</div>
    </div>
    </td>
    </tr>
  </tbody>
</table>

<h2>&nbsp;</h2>
<h2>List of Classes:</h2>
<h3>&nbsp;Class rand:&nbsp; &nbsp;<em>Random&nbsp;Variable&nbsp;Generator&nbsp;Class.</em></h3>

<table style="height: 100px; width: 574px; margin-left: 10px;" cellpadding="5px">
  <tbody>
    <tr>
    <td style="width: 173px;">choose(iter,k,duplicate)</td>
    <td style="width: 387px;">Choose k random items from iterable or string.</td>
    </tr>
    <tr>
    <td style="width: 173px;">integer(Frst,Lst)</td>
    <td style="width: 387px;">Choose integer in range [Frst,Lst]</td>
    </tr>
    <tr>
    <td style="width: 173px;">O1(decimal_nom=17)</td>
    <td style="width: 387px;">Return x in interval [0,1)</td>
    </tr>
    <tr>
    <td style="width: 173px;">number(Frst,Lst)</td>
    <td style="width: 387px;">Return x in interval [Frst,Lst]</td>
    </tr>
    <tr>
    <td style="width: 173px;">shuffle(iterable)</td>
    <td style="width: 387px;">Return shuffled version of iterable</td>
    </tr>
  </tbody>
</table>

<p>&nbsp;</p>
<h3>&nbsp; Class system:&nbsp; &nbsp;<em>Some system actions and information.</em></h3>

<table style="height: 100px; width: 574px; margin-left: 10px;" cellpadding="5px">
  <tbody>
    <tr>
    <td style="width: 173px;">accname()</td>
    <td style="width: 387px;">
    <div>
    <div>return&nbsp;account&nbsp;username&nbsp;you&nbsp;have&nbsp;logged&nbsp;in.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">pid()</td>
    <td style="width: 387px;">
    <div>
    <div>Get&nbsp;pid&nbsp;number&nbsp;of&nbsp;terminal&nbsp;and&nbsp;return&nbsp;it.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">disk_usage(path)</td>
    <td style="width: 387px;">########</td>
    </tr>
    <tr>
    <td style="width: 173px;">chdir</td>
    <td style="width: 387px;">Change directory of terminal.</td>
    </tr>
    <tr>
    <td style="width: 173px;">SHUT_DOWN()</td>
    <td style="width: 387px;">Shut Down the PC.</td>
    </tr>
    <tr>
    <td style="width: 173px;">RESTART()</td>
    <td style="width: 387px;">Restart the PC.</td>
    </tr>
    <tr>
    <td style="width: 173px;">terminal_size()</td>
    <td style="width: 387px;">Return terminal size in tuple&nbsp; (columns,lines).&nbsp;</td>
    </tr>
    <tr>
    <td style="width: 173px;">cwd()</td>
    <td style="width: 387px;">Return Carrent Working Directory.&nbsp;</td>
    </tr>
    <tr>
    <td style="width: 173px;">ip_global()</td>
    <td style="width: 387px;">Returns Global IP.</td>
    </tr>
    <tr>
    <td style="width: 173px;">ip_local()</td>
    <td style="width: 387px;">Returns Local IP.</td>
    </tr>
    <tr>
    <td style="width: 173px;">ram_total()</td>
    <td style="width: 387px;">Returns total ram of the system.</td>
    </tr>
    <tr>
    <td style="width: 173px;">ram_used()</td>
    <td style="width: 387px;">Returns Used Space of the ram of the system.</td>
    </tr>
    <tr>
    <td style="width: 173px;">ram_free()</td>
    <td style="width: 387px;">Returns Available (Free) space of system ram.</td>
    </tr>
    <tr>
    <td style="width: 173px;">boot_time()</td>
    <td style="width: 387px;">Return system boot time in seconds since the epoch.</td>
    </tr>
    <tr>
    <td style="width: 173px;">device_name()</td>
    <td style="width: 387px;">Returns Device Name</td>
    </tr>
    <tr>
    <td style="width: 173px;">ip_website(url)</td>
    <td style="width: 387px;">Returns url ip address</td>
    </tr>
    <tr>
    <td style="width: 173px;">win10_notification()</td>
    <td style="width: 387px;">Display windows 10 notification (READ DOCSTRING) (ONLY WIN10 SUPPORTED)</td>
    </tr>
    <tr>
    <td style="width: 173px;">cpu_count(logical=True)</td>
    <td style="width: 387px;">
    <div>
    <div>Return&nbsp;the&nbsp;number&nbsp;of&nbsp;logical/physical CPUs&nbsp;in&nbsp;the&nbsp;system</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">pyshell_execute_bit()</td>
    <td style="width: 387px;">
    <div>
    <div>To&nbsp;determine&nbsp;whether Python&nbsp;shell&nbsp;is&nbsp;executing&nbsp;in&nbsp;32bit&nbsp;or&nbsp;64bit</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">pids()</td>
    <td style="width: 387px;">
    <div>
    <div>
    <div>
    <div>Return&nbsp;a&nbsp;list&nbsp;of&nbsp;current&nbsp;running&nbsp;PIDs</div>
    </div>
    </div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">pid_exists(pid)</td>
    <td style="width: 387px;">Return True if pid exists else False</td>
    </tr>
    <tr>
    <td style="width: 173px;">
    <div>
    <div>cpu_percent()</div>
    </div>
    </td>
    <td style="width: 387px;">
    <div>
    <div>Return the&nbsp;current CPU&nbsp;utilization&nbsp;as&nbsp;a&nbsp;percentage</div>
    </div>
    </td>
    </tr>
  </tbody>
</table>

<p>&nbsp;</p>
<h3>&nbsp; Class files: (Static<strong style="font-size: 14px;">&nbsp;methods)&nbsp;</strong><em style="font-size: 14px;">Actions and information about files.</em></h3>

<table style="height: 100px; width: 574px; margin-left: 10px;" cellpadding="5px">
  <tbody>
    <tr>
    <td style="width: 173px;">size(path)</td>
    <td style="width: 387px;">
    <div>
    <div>Return&nbsp;size&nbsp;of&nbsp;the&nbsp;file&nbsp;in&nbsp;byte(s).&nbsp;Also&nbsp;work&nbsp;on&nbsp;directories.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">delete(path)</td>
    <td style="width: 387px;">
    <div>
    <div>Use&nbsp;this&nbsp;to&nbsp;delete&nbsp;a&nbsp;file&nbsp;(Not&nbsp;folder).</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">rename(path)</td>
    <td style="width: 387px;">
    <div>
    <div>Rename&nbsp;files&nbsp;with&nbsp;this&nbsp;function.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">abspath(path)</td>
    <td style="width: 387px;">
    <div>
    <div>Return&nbsp;absolute&nbsp;path&nbsp;of&nbsp;given&nbsp;path.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">exists(path)</td>
    <td style="width: 387px;">Return Boolean. If exists True, else: False</td>
    </tr>
    <tr>
    <td style="width: 173px;">mdftime(path)</td>
    <td style="width: 387px;">
    <div>
    <div>Get&nbsp;last&nbsp;modify&nbsp;time&nbsp;of&nbsp;the&nbsp;file.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">acstime(path)</td>
    <td style="width: 387px;">
    <div>
    <div>Get&nbsp;last&nbsp;access&nbsp;time&nbsp;of&nbsp;the&nbsp;file.</div>
    </div>
    </td>
    </tr>
    <tr>
    <td style="width: 173px;">move(src,dst)</td>
    <td style="width: 387px;">Move file from src to dst. (Read Doc String of copy func)</td>
    </tr>
    <tr>
    <td style="width: 173px;">copy(src,dst,metadata=True)</td>
    <td style="width: 387px;">Copy file (with metadata) from src to dst. (Also work on folders)</td>
    </tr>
    <tr>
    <td style="width: 173px;">hide(path)</td>
    <td style="width: 387px;">Hide given path. (It can be file or directory.)</td>
    </tr>
    <tr>
    <td style="width: 173px;">read_only(path,mode=True)</td>
    <td style="width: 387px;">Make file or folder read-only. (Read Doc String)</td>
    </tr>
    <tr>
    <td style="width: 173px;">read(path)</td>
    <td style="width: 387px;">Return content of the path</td>
    </tr>
    <tr>
    <td style="width: 173px;">write(path,text='',...)</td>
    <td style="width: 387px;">Same as write function.</td>
    </tr>
    <tr>
    <td style="width: 173px;">isdir(path)</td>
    <td style="width: 387px;">Return True for directory and False for others.</td>
    </tr>
    <tr>
    <td style="width: 173px;">isfile(path)</td>
    <td style="width: 387px;">Return True for file and False for others.</td>
    </tr>
    <tr>
    <td style="width: 173px;">is_hidden(path)</td>
    <td style="width: 387px;">Check whether path is hidden or not</td>
    </tr>
    <tr>
    <td style="width: 173px;">is_readonly(path)</td>
    <td style="width: 387px;">Check whether path is readonly or not</td>
    </tr>
    <tr>
    <td style="width: 173px;">search_file(pattern,path,mode)</td>
    <td style="width: 387px;">search for pattern in path (Read function doc string)</td>
    </tr>
    <tr>
    <td style="width: 173px;">search_content(path,word)</td>
    <td style="width: 387px;">Search for word in <span style="text-decoration: underline;">all</span> files in path, return list of files that contain word</td>
    </tr>
    <tr>
    <td style="width: 173px;">mkdir(path)</td>
    <td style="width: 387px;">Make directory (More than one if its possible!)</td>
    </tr>
    <tr>
    <td style="width: 173px;">generate_tree(dir_path)</td>
    <td style="width: 387px;">Returns a visual tree of dir_path</td>
    </tr>
    <tr>
    <td style="width: 173px;"><strong>&nbsp; &nbsp; &nbsp; &nbsp; MEMBERS&nbsp;(<em>Family)</em></strong></td>
    <td style="width: 387px;">&nbsp;</td>
    </tr>
    <tr>
    <td style="width: 193px;">MEMBERS.all_exactdir</td>
    <td style="width: 357px;">List of all&nbsp;things those are in exact directory</td>
    </tr>
    <tr>
    <td style="width: 193px;">
    <div>
    <div>MEMBERS.files_exactdir</div>
    </div>
    </td>
    <td style="width: 357px;">List of files which are in exact directory</td>
    </tr>
    <tr>
    <td style="width: 193px;">
    <div>
    <div>
    <div>
    <div>MEMBERS.dirs_exactdir</div>
    </div>
    </div>
    </div>
    </td>
    <td style="width: 357px;">List of dirs&nbsp; which are in exact directory</td>
    </tr>
    <tr>
    <td style="width: 193px;">MEMBERS.files_all</td>
    <td style="width: 357px;">List of files&nbsp;which are in exact directory and all sub-directories</td>
    </tr>
    <tr>
    <td style="width: 193px;">MEMBERS.files_all_sep</td>
    <td style="width: 357px;">List of files&nbsp;which are in exact directory and all sub-directories&nbsp;seprated by their directories</td>
    </tr>
    <tr>
    <td style="width: 193px;">
    <div>
    <div>
    <div>
    <div>MEMBERS.dirs_all</div>
    </div>
    </div>
    </div>
    </td>
    <td style="width: 357px;">List of&nbsp;directories (Exact dir and all sub-dirs)&nbsp;</td>
    </tr>
    <tr>
    <td style="width: 193px;">MEMBERS.all_all_sep</td>
    <td style="width: 357px;">List&nbsp; of everything thing in path (exact dir &amp; sub-dirs)</td>
    </tr>
    </tbody>
    </table>
    <p>&nbsp;</p>
    <h3>&nbsp;Class style:&nbsp; &nbsp; <em>Changing text Color,BG &amp; Style. (Read Doc String)</em></h3>
    <table style="height: 100px; width: 574px; margin-left: 10px;" cellpadding="5px">
    <tbody>
    <tr style="height: 15.0625px;">
    <td style="width: 173px; height: 15.0625px;">
    <p>print(txt,clr,BG,style,end)<br />(from v1.5.0)</p>
    </td>
    <td style="width: 387px; height: 15.0625px;">Print txt with selected color,BG,style.(Read Doc String)</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">switch(color,BG,style)</td>
    <td style="width: 387px; height: 18px;">Change Terminal Attributes Until another Call.</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">
    <div>
    <div>switch_default()</div>
    </div>
    </td>
    <td style="width: 387px; height: 18px;">Restore Terminal Attributes.</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">
    <div>
    <div>reset</div>
    </div>
    </td>
    <td style="width: 387px; height: 18px;">switch_default()</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">
    <div>
    <div>log_&nbsp; <em>(Family)</em></div>
    </div>
    </td>
    <td style="width: 387px; height: 18px;">5 Different Style.print with ready color and style</td>
    </tr>
  </tbody>
</table>

<p>&nbsp;</p>
<h3>&nbsp;Class record:&nbsp; &nbsp;<em>Record time of a certain actions. (Read Doc String)</em></h3>
<table style="height: 100px; width: 574px; margin-left: 10px;" cellpadding="5px">
  <tbody>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">__init__()</td>
    <td style="width: 387px; height: 18px;">Set Start Time.</td>
    </tr>
    <tr style="height: 30px;">
    <td style="width: 173px; height: 30px;">self.stop(self)</td>
    <td style="width: 387px; height: 30px;">Stops Recording (You can not lap anymore)</td>
    </tr>
    <tr style="height: 23.8125px;">
    <td style="width: 173px; height: 23.8125px;">self.lap(self, save=True, round=15)</td>
    <td style="width: 387px; height: 23.8125px;">Rreturn time between start time. if save==True: add that time to self.laps</td>
    </tr>
    <tr style="height: 23.8125px;">
    <td style="width: 173px; height: 23.8125px;">self.laps</td>
    <td style="width: 387px; height: 23.8125px;">A list that contains all laps you have done</td>
    </tr>
    <tr style="height: 23.8125px;">
    <td style="width: 173px; height: 23.8125px;">self.reset(self, start=False)</td>
    <td style="width: 387px; height: 23.8125px;">Empty self.laps, if start is True: set start time to now</td>
    </tr>
    <tr style="height: 23.8125px;">
    <td style="width: 173px; height: 23.8125px;">self.last_lap(save=True)</td>
    <td style="width: 387px; height: 23.8125px;">Return elapsed time from last lap (save it in self.laps if save is true)</td>
    </tr>
    </tbody>
    </table>
    <p>&nbsp;</p>
    <h2>List of Objects:</h2>
    <h3>&nbsp; &nbsp; &nbsp;object Tuple:<strong>&nbsp;</strong><em>It's like built-in tuple except it's faster and it has more features!</em></h3>
    <h4>&nbsp; &nbsp; &nbsp; &nbsp; &nbsp;Descryption:</h4>
    <p><em>&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;&nbsp;</em>Tuple is here with built-in tuple object and much more features.</p>
    <p>&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; You can add, remove, replace or even use __setitem__ Tuple object.</p>
    <p>&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; I recommend using <em><strong>tuple= rx.Tuple</strong></em> that can make it relay easier for you o work.</p>
    <h4>&nbsp; &nbsp; &nbsp; &nbsp; &nbsp;Supports:<em>&nbsp; &nbsp;indexing - len - hash&nbsp; - bool - __add__&nbsp;</em></h4>
    <table style="height: 196px; width: 588px; margin-left: 45px;">
    <tbody>
    <tr style="height: 18px;">
    <td style="width: 155px; height: 18px;"><strong>Tuple(*var,one=False)</strong></td>
    <td style="width: 417px; height: 18px;"><strong>Create Tuple object with *var members</strong></td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 155px; height: 18px;">self.add(*vars)</td>
    <td style="width: 417px; height: 18px;">Add *vars to self</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 155px; height: 18px;">self.force(*vars)</td>
    <td style="width: 417px; height: 18px;">self.add</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 155px; height: 18px;">self.remove(*vars)</td>
    <td style="width: 417px; height: 18px;">Remove *vars from self (Ignore it if it's not in self).</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 155px; height: 18px;">self.erase(*vars)</td>
    <td style="width: 417px; height: 18px;">self.remove</td>
    </tr>
    <tr style="height: 36px;">
    <td style="width: 155px; height: 36px;">self.replace(ind,var)</td>
    <td style="width: 417px; height: 36px;">Replace self[index] with var. (index can be int or anything thats in self</td>
    </tr>
    <tr style="height: 36px;">
    <td style="width: 155px; height: 36px;">self.pop(ind)</td>
    <td style="width: 417px; height: 36px;">Remove member with index of 'index' from self</td>
    </tr>
    </tr>
    <tr style="height: 19.5781px;">
    <td style="width: 155px; height: 19.5781px;">self[index]=var</td>
    <td style="width: 417px; height: 19.5781px;">Set self[index] to var. (Like lists) (it does not replace)</td>
    </tr>
  </tbody>
</table>

<p>&nbsp;</p>
<h3>&nbsp;Class Decorator:&nbsp; &nbsp;<em>Useful decorators you might want to use</em></h3>
<table style="height: 100px; width: 574px; margin-left: 10px;" cellpadding="5px">
  <tbody>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">Check_Type</td>
    <td style="width: 387px; height: 18px;">Decorator that raise TypeError if function argument type is wrong (Read Help)</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">overload</td>
    <td style="width: 387px; height: 18px;">Make your function accept different kind of argument and structure with defining it more than once</td>
    </tr>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">attach_to_all</td>
    <td style="width: 387px; height: 18px;">Attach Decorator.decorator_all to all functions of a class (Class decorator)</td>
    <tr style="height: 18px;">
    <td style="width: 173px; height: 18px;">abstractmethod</td>
    <td style="width: 387px; height: 18px;">A decorator indicating abstract methods.</td>
    </tr>
  </tbody>
</table>

<p>&nbsp;</p>
<h2>Recommended to:</h2>

 **- Using an IDE that shows Function and Class Help is highly recommended.**  **([VS Code](https://code.visualstudio.com/ "Microsoft VS Code") -** **[PyCharm](https://www.jetbrains.com/pycharm/ "Microsoft Visual Studio Code"))**

####  - Using "from rx7 import FUNC\_or\_CLASS"

####  - Using "import rx7 as rx"
<p>&nbsp;</p>
 Upgrade:
---------

### &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;pip install --upgrade rx7

 Use These Commands in Terminal:
--------------------------------

### &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; $ rx7 color           (To show help for style class)
 
### &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; $ rx7 help            (To open this page that contains help)

Versions Information:
---------------------

        Releases are like this:        1.0.0

 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.1.1

 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;   ⋮

 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.2.0

        First number is very important bacause it's for Realy Big new features and changes.

        Second number is important but not like first number because it contains some changes and new features (RECOMMENDED for upgrading package)

        But 3rd number is not important because it's for changing packege codes order and you won't lose anything if you        don't install it.

        Numbers are not always in order like: 1,2,3,4,...  , Some times they are different like: 1.2.4.8,..._

Releases:
---------

####        (+ for new features, \* for changes)
<table style="height: 10px; margin-left: 10px; width: 519px;" cellpadding="5">
<tbody>
<tr style="height: 42px;">
<td style="width: 119px; height: 42px; text-align: center;"><strong>Version</strong></td>
<td style="width: 153px; height: 42px; text-align: center;"><strong>Release Date</strong></td>
<td style="width: 513px; height: 42px; text-align: center;"><strong>New Features &amp; Changes</strong></td>
</tr>

</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.9.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">12/15/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">+ Decorator Class (attach_to_all ---&nbsp;Check_Type)</div>
<div style="text-align: left;">* IMPORT SPEED IS 20x FASTER!</div>
<div style="text-align: left;">+ argv (sys.argv)</div>
<div style="text-align: left;">- Record.EndError</div>
<div style="text-align: left;">+ overload (Decorator.overload)</div>
<div style="text-align: left;">+ ABC,ABCMeta</div>
</td>
</tr>

<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.8.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">11/15/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">+ Decorator Class (attach_to_all ---&nbsp;Check_Type)</div>
<div style="text-align: left;">+ pop()</div>
<div style="text-align: left;">+ Tuple.pop()</div>
<div style="text-align: left;">+ Record.timeit()</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.7.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">10/15/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">+ getpass()</div>
<div style="text-align: left;">+ style.log_ Family</div>
<div style="text-align: left;">+ style.reset() = style.switch_default()</div>
<div style="text-align: left;">+ load_module()</div>
<div style="text-align: left;">+ record.last_lap()</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.6.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">10/1/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">+ system.cpu_percent()</div>
<div style="text-align: left;">+ system.pid_exists()</div>
<div style="text-align: left;">+ Progressbar()&nbsp;<em>(Generator)</em></div>
<div style="text-align: left;">+ pixel_color()</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.5.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">09/15/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">+ Check_Type decorator</div>
<div style="text-align: left;">+ system.pyshell_execute_bit()</div>
<div style="text-align: left;">+ system.pids()</div>
<div style="text-align: left;">+ record.lap&nbsp;round&nbsp;arg</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.4.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">09/01/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">* rand -&gt; random</div>
<div>
<div style="text-align: left;">+ random.shuffle()</div>
<div>
<div style="text-align: left;">+ repeat function supports parameters</div>
<div>
<div style="text-align: left;">+ sleep = wait&nbsp; &nbsp;---&nbsp; &nbsp;clear = cls&nbsp; &nbsp;---&nbsp; &nbsp;default_input = Input</div>
<div style="text-align: left;">+ system.cpu_count()</div>
</div>
</div>
</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.3.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">08/19/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<p style="text-align: left;">+ extract()</p>
<p style="text-align: left;">+ screenshot()</p>
<p style="text-align: left;">+ func_info()</p>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.2.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">08/03/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<p style="text-align: left;">+ download()</p>
<p style="text-align: left;">+ system.ip_website()</p>
<p style="text-align: left;">+ system.win10_notification</p>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;">2.1.0</p>
</td>
<td style="width: 153px; height: 25px; text-align: center;">07/15/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<p style="text-align: left;">* style class better performance in linux</p>
<p style="text-align: left;">+&nbsp;<span style="text-align: center;">MEMBERS&nbsp;group&nbsp;in&nbsp;files&nbsp;class</span></p>
<p style="text-align: left;"><span style="text-align: center;">+ File object:&nbsp; self.basename, self.ext</span></p>
<p style="text-align: left;"><span style="text-align: center;">+ system.device_name()</span></p>
<p style="text-align: left;"><span style="text-align: center;">+&nbsp;</span><span style="text-align: center;">active_window_title() --- open_image()</span></p>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">
<p style="text-align: center;"><strong>2.0.0</strong></p>
</td>
<td style="width: 153px; height: 25px; text-align: center;"><strong>07/01/2020</strong></td>
<td style="width: 513px; height: 25px; text-align: center;">
<p style="text-align: left;">+ <strong>Tuple object&nbsp; &nbsp;---&nbsp; &nbsp;rxobject</strong></p>
<p style="text-align: left;">+ record.reset()&nbsp; &nbsp;---&nbsp; &nbsp;record.lap new arg</p>
<p style="text-align: left;">+ New methods of files</p>
<p style="text-align: left;">&nbsp; &nbsp; &nbsp; files.is_readonly()&nbsp; &nbsp;---&nbsp; &nbsp;files.is_hidden()</p>
<p style="text-align: left;"><strong>&nbsp; &nbsp; &nbsp; files.search_file()&nbsp; &nbsp;---&nbsp; &nbsp;files.search_content()</strong></p>
<p style="text-align: left;">&nbsp; &nbsp; &nbsp; files.copy new arg</p>
<p style="text-align: left;"><strong>&nbsp; &nbsp; &nbsp; files.generate_tree()</strong></p>
<p style="text-align: left;"><strong>+ File.MEMBERS </strong>(when in File(path), path is a directory&nbsp; (self.MEMBERS.TYPE_PATH)</p>
<p style="text-align: left;"><strong>+ File.tree&nbsp; &nbsp; ---&nbsp; &nbsp; &nbsp;File.tree_dirs</strong></p>
<p style="text-align: left;"><strong>+ Input()</strong>&nbsp; <em>(Only on windows)</em></p>
<p style="text-align: left;">+ restart_app()</p>
<p style="text-align: left;">&nbsp;</p>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">1.9.0</td>
<td style="width: 153px; height: 25px;">&nbsp; 06/09/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<p style="text-align: left;">* re() --&gt; repeat()</p>
<p style="text-align: left;">+ New Methods of System Class:&nbsp; ip_global(),&nbsp;ip_local(),&nbsp;ram_free(), ram_percent(),&nbsp;ram_total(),&nbsp;ram_used(), boot_time()</p>
<p style="text-align: left;">+ convert_bytes()</p>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">1.8.0</td>
<td style="width: 153px; height: 25px; text-align: center;">05/24/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">+ style.switch_default()</div>
<div>
<div style="text-align: left;">+ Now Linux&nbsp;supports&nbsp;cls()</div>
<div>
<div style="text-align: left;">+ style&nbsp;object:&nbsp;supports&nbsp;multiply,add,index</div>
<div>
<div style="text-align: left;">+ rand.choice Choose &gt;1 &amp; duplicate</div>
<div style="text-align: left;">* rand.choice --&gt; rand.choose</div>
</div>
</div>
</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">1.7.0</td>
<td style="width: 153px; height: 25px; text-align: center;">&nbsp; 05/08/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div>
<div style="text-align: left;">+ call_later()&nbsp;&nbsp;-&nbsp;&nbsp;wait_for()</div>
<div style="text-align: left;">+ terminal_size()&nbsp;&nbsp;-&nbsp;&nbsp;cwd()</div>
<div style="text-align: left;">+ right_port,left_port arg for progressbar()</div>
<div style="text-align: left;">+ file.remove() for static usage</div>
<div style="text-align: left;">+ self.type in file class</div>
<div style="text-align: left;">+ if in file(x), x is a directory:<br />x.files , x.file_list , x.all_files , x.all_files_sep</div>
<div style="text-align: left;">+ file.isdir() , file.isfile() for static usage.</div>
<div style="text-align: left;">* string() =&gt; cons_int()</div>
<div style="text-align: left;">* progressbar() arg names</div>
<div style="text-align: left;">* file.delete() and file.delete_dir()&nbsp;=&gt;&nbsp;delete()</div>
<div style="text-align: left;">* Change replace() and insert() args oreder</div>
</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">1.5.0</td>
<td style="width: 153px; height: 25px; text-align: center;">04/21/2020</td>
<td style="width: 513px; height: 25px; text-align: left;">
<div>
<div>
<div>+ 'replace' and insert 'functions' for tuples</div>
<div>+ 'end' arg for style.print()</div>
<div>+ 'self.laps' in record class will display all laps</div>
<div>* style.text =&gt; style.print</div>
<div>* record.stop =&gt; record.lap</div>
<div>* now 'record.stop()' will stop recording.</div>
</div>
</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center; text-align: center;">1.3.0</td>
<td style="width: 153px; height: 25px;">&nbsp;04/08/2020</td>
<td style="width: 513px; height: 25px; text-align: center;">
<div style="text-align: left;">+ __init__ &amp; read &amp; write &amp; content&nbsp; func&nbsp;of&nbsp;file&nbsp;class</div>
<div style="text-align: left;">* Prgoressbar&nbsp;default&nbsp;args</div>
</td>
</tr>
<tr style="height: 25px;">
<td style="width: 119px; height: 25px; text-align-last: center;">
<p style="text-align: center;">1.0.0</p>
</td>
<td style="width: 153px; height: 25px;">
<p style="text-align: center;">03/18/2020</p>
</td>
<td style="width: 513px; height: 25px; text-align: center;">####</td>
</tr>
</tbody>
</table>